#' Example multi-concentration screening data
#'
#' A dataset contains example data for a primary inhibition assay and the parallel cytotoxicity assay
#'
#' @format See vignette for description of the demo data.
#'
#'

"demo_mc"

#' Normalized example multi-concentration screening data
#'
#' A dataset contains normalized example data for a primary inhibition assay and the parallel cytotoxicity assay
#'
#' @format See vignette for description of the demo data.
#'
#'

"demo_mc_norm"
